leaftools.label_leaves_in_expr_with_prolated_leaf_duration
==========================================================

.. autofunction:: abjad.tools.leaftools.label_leaves_in_expr_with_prolated_leaf_duration.label_leaves_in_expr_with_prolated_leaf_duration
